@@ -17,7 +17,7 @@ has 'shape' => (
     }
 );
 
-override('pack', sub {
+override('finalize', sub {
     my ($self) = @_;
 
     my $clicker = $self->clicker;
